@@ -89,13 +89,19 @@ def analyze():
     df['GPUs'] = df['GPUs'].astype(str).str.split(':').str[1]
     df['Nodes'] = df['Nodes'].astype(str).str.split('=').str[1]
 
-    pd.set_option('display.max_colwidth',1000)
+    #pd.set_option('display.max_colwidth',1000)
+    #pd.set_option('display.max_rows', df.shape[0]+1)
+    #pd.set_option('display.max_columns', None)
+    #pd.set_option('display.expand_frame_repr', False)
+    #pd.set_option('max_colwidth', -1)
 
     df = df.sort_values(by=['Perfomance'], ascending=False)
     df = df.reset_index()
     df = df.reset_index(drop=True)
     df_new=df.drop(['index'],axis=1)
+    pd.set_option('display.max_colwidth',1000)
+    pd.set_option('display.max_rows', 1000)
     with open('./Benchmark_Perfomance.png', 'a') as fo:
         fo.write(df_new.__repr__())
 
-
+    
